( cd usr/man/man3 ; rm -rf acl_extended_file_nofollow.3.gz )
( cd usr/man/man3 ; ln -sf acl_extended_file.3.gz acl_extended_file_nofollow.3.gz )
( cd usr/lib ; rm -rf libacl.so )
( cd usr/lib ; ln -sf /lib/libacl.so.1 libacl.so )
( cd lib ; rm -rf libacl.so.1 )
( cd lib ; ln -sf libacl.so.1.1.0 libacl.so.1 )
